from .CalculadoraPrincipal import Calculadora

resultado = Calculadora(22,2,1)

print(resultado.sumatoria())

def obs():
    print("Holaaaaa")
